@@ -59,8 +59,27 @@ class KyotoCabinetGraph(BaseGraph):
             return UNDEFINED  # Not returning None, as None is a valid value
         return json.loads(raw_data)
 
+    def _bulk_get(self, txn, keys):
+        result = {}
+        key_raw_datas = self._db.get_bulk(keys)
+        for key, raw_data in key_raw_datas.items():
+            result[key] = json.loads(raw_data)
+        return result
+
     def _set(self, txn, key, value):
-        return self._db.set(key, json.dumps(value))
+        res = self._db.set(key, json.dumps(value))
+        if not(res):  # pragma : no cover
+            raise GrapheekDataKyotoCabinetException('KyotoCabinet : error while saving')
+        return res
+
+    def _bulk_set(self, txn, updates):
+        dic = {}
+        for key, value in updates.items():
+            dic[key] = json.dumps(value)
+        res = self._db.set_bulk(dic)
+        if res == -1:  # pragma : no cover
+            raise GrapheekDataKyotoCabinetException('KyotoCabinet : error while saving')
+        return res
 
     def _remove(self, txn, key):
         # Contrary to LocalMemoryGraph implementation, it is not needed to wrap
@@ -69,6 +88,12 @@ class KyotoCabinetGraph(BaseGraph):
         # Thus ... _removemethod is idempotent (cf LocalMemoryGraph _remove method comment)
         self._db.remove(key)
 
+    def _bulk_remove(self, txn, keys):
+        res = self._db.remove_bulk(list(keys))
+        if res == -1:  # pragma : no cover
+            raise GrapheekDataKyotoCabinetException('KyotoCabinet : error while saving')
+        return res
+
     def _remove_prefix(self, txn, prefix):
         keys = self._db.match_prefix(prefix)
         self._db.remove_bulk(keys)
@@ -79,7 +104,10 @@ class KyotoCabinetGraph(BaseGraph):
     # in the case of KyotoCabinet would involve json deserialization followed by a serialization
 
     def _init_lst(self, txn, key):
-        self._db.set(key, '')
+        res = self._db.set(key, '')
+        if not(res):  # pragma : no cover
+            raise GrapheekDataKyotoCabinetException('KyotoCabinet : error while saving')
+        return res
 
     def _get_lst(self, txn, key):
         value = self._db.get(key)
@@ -89,6 +117,13 @@ class KyotoCabinetGraph(BaseGraph):
         # And why resulting list is sliced from 1
         return map(int, value.split('|')[1:])
 
+    def _set_lst(self, txn, key, values):
+        newval = '|'.join([str(value) for value in values])
+        res = self._db.set(key, '|' + newval)
+        if not(res):  # pragma : no cover
+            raise GrapheekDataKyotoCabinetException('KyotoCabinet : error while saving')
+        return res
+
     def _bulk_get_lst(self, txn, keys):
         dic_values = self._db.get_bulk(keys)
         results = []
@@ -100,13 +135,13 @@ class KyotoCabinetGraph(BaseGraph):
                 results.append(map(int, values.split('|')[1:]))
         return results
 
-    def _count_lst(self, txn, key):
-        value = self._db.get(key)
-        return value.count('|')
-
     def _append_to_lst(self, txn, key, value):
         self._db.append(key, '|' + str(value))
 
+    def _bulk_append_to_lst(self, txn, key, values):
+        newval = '|'.join([str(value) for value in values])
+        self._db.append(key, '|' + newval)
+
     def _remove_from_lst(self, txn, key, value):
         old = self._db.get(key)
         # Caution : we are only removing ONE occurence
@@ -114,4 +149,22 @@ class KyotoCabinetGraph(BaseGraph):
         # For instance, it lst contains neighbour node, we need to remove only one occurence
         # cause current entity and neighbour node can be linked multiple time
         new = old.replace('|%s' % value, '', 1)
-        self._db.set(key, new)
+        if new == old:
+            raise ValueError("list.remove(x): x not in list")
+        res = self._db.set(key, new)
+        if not(res):  # pragma : no cover
+            raise GrapheekDataKyotoCabinetException('KyotoCabinet : error while saving')
+        return res
+
+    def _bulk_remove_from_lst(self, txn, key, values):
+        old = self._db.get(key)
+        assert(len(values))
+        new = old
+        for value in values:
+            new = new.replace('|%s' % value, '', 1)
+        if new == old:  # pragma : no cover
+            raise ValueError("list.remove(x): x not in list")
+        res = self._db.set(key, new)
+        if not(res):  # pragma : no cover
+            raise GrapheekDataKyotoCabinetException('KyotoCabinet : error while saving')
+        return res
