@@ -43,8 +43,6 @@ class LmdbGraph(BaseGraph):
             return txn.get(key, UNDEFINED) != UNDEFINED
 
     def _get(self, txn, key):
-        if key is None:
-            return UNDEFINED
         if txn is not None:
             raw_data = txn.get(key, UNDEFINED)
             if raw_data == UNDEFINED:
@@ -59,12 +57,28 @@ class LmdbGraph(BaseGraph):
                 res = json.loads(raw_data)
                 return res
 
+    def _bulk_get(self, txn, keys):
+        dic = {}
+        for key in keys:
+            value = self._get(txn, key)
+            if value != UNDEFINED:
+                dic[key] = value
+        return dic
+
     def _set(self, txn, key, value):
         txn.put(key, json.dumps(value))
 
+    def _bulk_set(self, txn, updates):
+        for key, value in updates.items():
+            self._set(txn, key, value)
+
     def _remove(self, txn, key):
         txn.delete(key)
 
+    def _bulk_remove(self, txn, keys):
+        for key in keys:
+            txn.delete(key)
+
     def _remove_prefix(self, txn, prefix):
         cursor = txn.cursor()
         for key, _ in cursor:
