@@ -368,22 +368,19 @@ class ProxyGraph(GraphReadWrite):
         command = ['add_node_index' if kind == KIND_VERTEX else 'add_edge_index', args, {}]
         return self._request([command])
 
-    def add_node_index(self, *args):
-        return self._add_entity_index(KIND_VERTEX, *args)
+    def add_node_index(self, *fields):
+        return self._add_entity_index(KIND_VERTEX, *fields)
 
-    def add_edge_index(self, *args):
-        return self._add_entity_index(KIND_EDGE, *args)
-
-    def _get_entity_indexes(self, kind):
-        assert(kind in (KIND_EDGE, KIND_VERTEX))
-        command = ['_get_entity_indexes', [kind], {}]
-        return self._request([command])
+    def add_edge_index(self, *fields):
+        return self._add_entity_index(KIND_EDGE, *fields)
 
     def get_node_indexes(self):
-        return self._get_entity_indexes(KIND_VERTEX)
+        command = ['get_node_indexes', [], {}]
+        return self._request([command])
 
     def get_edge_indexes(self):
-        return self._get_entity_indexes(KIND_EDGE)
+        command = ['get_edge_indexes', [], {}]
+        return self._request([command])
 
     def _remove_entity_index(self, kind, *args):
         assert(kind in (KIND_EDGE, KIND_VERTEX))
