@@ -15,7 +15,7 @@ from ConfigParser import RawConfigParser
 
 import zmq.green as zmq
 
-from grapheekdb.backends.data.base import EntityIterator, Node, Edge
+from grapheekdb.backends.data.base import EntityAggregate, EntityIterator, Node, Edge
 from grapheekdb import __version__
 from grapheekdb.lib.exceptions import GrapheekMarshallingException
 
@@ -46,7 +46,7 @@ def marshall(item):
             '_i': item.get_id(),
             'd': marshall(item.data())
         }
-    elif isinstance(item, EntityIterator):
+    elif isinstance(item, (EntityAggregate, EntityIterator)):
         return [marshall(x) for x in item]
     raise GrapheekMarshallingException('Unknown type or instance : %s - %s' % (type(item), item))
 
